==> faxtomail-ui-swing-1.0-sources.jar: com/franciaflex/faxtomail/ui/swing/actions/EditAttachmentAction.java <==
package com.franciaflex.faxtomail.ui.swing.actions;

/*
 * #%L
 * FaxToMail :: UI
 * $Id: EditAttachmentAction.java 660 2014-10-02 11:30:33Z kmorin $
 * $HeadURL: http://svn.codelutin.com/faxtomail/tags/faxtomail-1.0/faxtomail-ui-swing/src/main/java/com/franciaflex/faxtomail/ui/swing/actions/EditAttachmentAction.java $
 * %%
 * Copyright (C) 2014 Mac-Groupe, Code Lutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.franciaflex.faxtomail.persistence.entities.Attachment;
import com.franciaflex.faxtomail.ui.swing.content.MainUI;
import com.franciaflex.faxtomail.ui.swing.content.attachment.AttachmentEditorUI;
import com.franciaflex.faxtomail.ui.swing.content.attachment.AttachmentEditorUIHandler;
import com.franciaflex.faxtomail.ui.swing.content.attachment.AttachmentEditorUIModel;
import com.franciaflex.faxtomail.ui.swing.content.pdfeditor.PDFEditorUI;
import com.franciaflex.faxtomail.ui.swing.content.pdfeditor.PDFEditorUIModel;
import com.franciaflex.faxtomail.ui.swing.util.FaxToMailUIUtil;

import javax.swing.*;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import static org.nuiton.i18n.I18n.t;

/**
 * @author Kevin Morin (Code Lutin)
 *
 */
public class EditAttachmentAction extends AbstractFaxToMailAction<AttachmentEditorUIModel, AttachmentEditorUI, AttachmentEditorUIHandler> {

    protected Attachment attachment;
    protected PDFEditorUI dialogContent;
    protected JFrame frame;

    public EditAttachmentAction(AttachmentEditorUIHandler handler) {
        super(handler, false);
    }

    public void setAttachment(Attachment attachment) {
        this.attachment = attachment;
        String attachmentName = attachment.getEditedFileName() != null ? attachment.getEditedFileName() : attachment.getOriginalFileName();
        setActionDescription(t("faxtomail.action.attachment.edit.tip", attachmentName));
    }

    @Override
    public void doAction() throws Exception {
        getModel().fireAttachmentOpened(attachment, false);

        FaxToMailUIUtil.forceAttachmentFileLoading(getContext(), attachment);

        dialogContent = new PDFEditorUI(getUI());
        PDFEditorUIModel pdfEditorUIModel = dialogContent.getModel();
        pdfEditorUIModel.fromEntity(attachment);
        pdfEditorUIModel.setDemand(getContext().getCurrentEmail());
    }

    @Override
    public void postSuccessAction() {
        super.postSuccessAction();
        MainUI mainUI = getContext().getMainUI();
        frame = getHandler().openModalFrame(dialogContent, attachment.getOriginalFileName(), mainUI.getSize());
        frame.addWindowListener(new WindowAdapter() {
            @Override
            public void windowClosing(WindowEvent e) {
            }

            @Override
            public void windowClosed(WindowEvent e) {
                dialogContent.getModel().toEntity(attachment);
            }
        });
    }

    @Override
    protected void releaseAction() {
        super.releaseAction();
        if (frame != null) {
            frame.toFront();
            frame = null;
        }
    }
}

==> faxtomail-ui-swing-1.1.4-sources.jar: com/franciaflex/faxtomail/ui/swing/actions/EditAttachmentAction.java <==
package com.franciaflex.faxtomail.ui.swing.actions;

/*
 * #%L
 * FaxToMail :: UI
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2014 Mac-Groupe, Code Lutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.franciaflex.faxtomail.persistence.entities.Attachment;
import com.franciaflex.faxtomail.ui.swing.content.MainUI;
import com.franciaflex.faxtomail.ui.swing.content.attachment.AttachmentEditorUI;
import com.franciaflex.faxtomail.ui.swing.content.attachment.AttachmentEditorUIHandler;
import com.franciaflex.faxtomail.ui.swing.content.attachment.AttachmentEditorUIModel;
import com.franciaflex.faxtomail.ui.swing.content.pdfeditor.PDFEditorUI;
import com.franciaflex.faxtomail.ui.swing.content.pdfeditor.PDFEditorUIModel;
import com.franciaflex.faxtomail.ui.swing.util.FaxToMailUIUtil;

import javax.swing.*;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import static org.nuiton.i18n.I18n.t;

/**
 * @author Kevin Morin (Code Lutin)
 *
 */
public class EditAttachmentAction extends AbstractFaxToMailAction<AttachmentEditorUIModel, AttachmentEditorUI, AttachmentEditorUIHandler> {

    protected Attachment attachment;
    protected PDFEditorUI dialogContent;
    protected JFrame frame;

    public EditAttachmentAction(AttachmentEditorUIHandler handler, Attachment attachment) {
        super(handler, false);
        this.attachment = attachment;
        String attachmentName = attachment.getEditedFileName() != null ? attachment.getEditedFileName() : attachment.getOriginalFileName();
        setActionDescription(t("faxtomail.action.attachment.edit.tip", attachmentName));
    }

    @Override
    public void doAction() throws Exception {
        getModel().fireAttachmentOpened(attachment, false);

        FaxToMailUIUtil.forceAttachmentFileLoading(getContext(), attachment);

        dialogContent = new PDFEditorUI(getUI());
        PDFEditorUIModel pdfEditorUIModel = dialogContent.getModel();
        pdfEditorUIModel.fromEntity(attachment);
        pdfEditorUIModel.setDemand(getContext().getCurrentEmail());
    }

    @Override
    public void postSuccessAction() {
        super.postSuccessAction();
        MainUI mainUI = getContext().getMainUI();
        frame = getHandler().openFrame(dialogContent, attachment.getOriginalFileName(), mainUI.getSize());

        frame.addWindowListener(new WindowAdapter() {
            @Override
            public void windowClosed(WindowEvent e) {
                dialogContent.getModel().toEntity(attachment);
            }
        });
    }

    @Override
    protected void releaseAction() {
        super.releaseAction();
        SwingUtilities.invokeLater(new Runnable() {
            @Override
            public void run() {
                if (frame != null) {
                    frame.toFront();
                    frame = null;
                }
            }
        });
    }
}
